# Copyright (C) 2002-2023 CERN for the benefit of the ATLAS collaboration

from AthenaConfiguration.ComponentFactory import CompFactory
from AthenaConfiguration.ComponentAccumulator import ComponentAccumulator

def MonitoredCfg(flags):
    result = ComponentAccumulator()
    monAlg = CompFactory.MonitoredAlg('MonAlg')

    from AthenaMonitoringKernel.GenericMonitoringTool import GenericMonitoringTool
    monTool = GenericMonitoringTool(flags, 'MonTool')

    #monTool.HistPath = 'MyGroup/MySubDir'  # default is the parent name of MonTool
    monTool.defineHistogram( 'nTracks', path='EXPERT', type='TH1F', title='Counts',
                             xbins=10, xmin=0, xmax=10 )
    monTool.defineHistogram( 'eta', path='EXPERT', type='TH1F', title='#eta;;Entries',
                             xbins=30, xmin=-3, xmax=3 )
    monTool.defineHistogram( 'AbsPhi', path='EXPERT', type='TH1F', title='|#phi|;;Entries',
                             xbins=10, xmin=0, xmax=3.15 )
    monTool.defineHistogram( 'eta,AbsPhi', path='EXPERT', type='TH2F', title='#eta vs #phi',
                             xbins=15, xmin=-3, xmax=3, ybins=15, ymin=0, ymax=3.15 )
    monTool.defineHistogram( 'TIME_execute', path='EXPERT', type='TH1F', title='Time for execute',
                             xbins=100, xmin=0, xmax=100 )

    monAlg.MonTool = monTool

    histSvc = CompFactory.THistSvc(Output = ["EXPERT DATAFILE='expert-monitoring.root', OPT='RECREATE'"])

    result.addEventAlgo(monAlg)
    result.addService(histSvc)
    return result


if __name__=="__main__":
    from AthenaConfiguration.MainServicesConfig import MainServicesCfg
    from AthenaConfiguration.AllConfigFlags import initConfigFlags
    flags = initConfigFlags()
    flags.Exec.MaxEvents = 10
    cfg = MainServicesCfg(flags)
    cfg.merge(MonitoredCfg(flags))
    cfg.run()
