// This file's extension implies that it's C, but it's really -*- C++ -*-.
/*
 * Copyright (C) 2002-2023 CERN for the benefit of the ATLAS collaboration.
 */
/**
 * @file CxxUtils/normalizeFunctionName.h
 * @author scott snyder <snyder@bnl.gov>
 * @date Aug, 2023
 * @brief Normalize a pretty-printed C++ function name,
 */


#ifndef CXXUTILS_NORMALIZEFUNCTIONNAME_H
#define CXXUTILS_NORMALIZEFUNCTIONNAME_H


#include <string>


namespace CxxUtils {


/**
 * @brief Normalize a pretty-printed C++ function name.
 * @param fname The name to normalize.
 *
 * A C++ compiler can provide a complete printable name of the current function,
 * though for example __PRETTY_FUNCTION__.  This is useful to include in
 * diagnostic messages.  However, the exact string generated by different
 * compilers may differ slightly.  This can then cause issues if one is
 * trying to compare the output of tests to an expected reference.
 *
 * This function tries to normalize the function name strings so that they
 * are the same, at least between gcc and clang.
 */
std::string normalizeFunctionName (const std::string& fname);


} // namespace CxxUtils


#endif // not CXXUTILS_NORMALIZEFUNCTIONNAME_H
