/*
  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
*/

#ifndef GoodRunsLists_GoodRunsListSelectorTool_H
#define GoodRunsLists_GoodRunsListSelectorTool_H

/** @file GoodRunsListSelectorTool.h
 *  @brief This file contains the class definition for the GoodRunsListSelectorTool class.
 *  @author Max Baak <mbaak@cern.ch>
 **/

#include "GoodRunsLists/IGoodRunsListSelectorTool.h"
#include "AthenaBaseComps/AthAlgTool.h"
#include "AthenaKernel/IAthenaEvtLoopPreSelectTool.h"
#include "GoodRunsLists/RegularFormula.h"

#include <vector>
#include <string>
#include <map>

//typedef std::pair< std::vector<std::string>, std::vector<std::string> > vvPair; 

/** @class GoodRunsListSelectorTool
 *  @brief This file contains the class definition for the GoodRunsListSelectorTool class.
 **/

class TFormula;

namespace Root {
  class TGRLCollection;
  class TGoodRunsListReader;
}

class GoodRunsListSelectorTool : public extends<AthAlgTool, IGoodRunsListSelectorTool, IAthenaEvtLoopPreSelectTool>
{
 public:    
  GoodRunsListSelectorTool( const std::string&, const std::string&, const IInterface* );
  virtual ~GoodRunsListSelectorTool();

  /// Initialize AlgTool
  StatusCode initialize();
  /// called for each event by EventSelector to decide if the event should be passed
  bool passEvent(const EventIDBase& pEvent) ;
  /// Finalize AlgTool
  StatusCode finalize();

  /// called for each event by GoodRunsListSelectorAlg to decide if the event should be passed
  bool passRunLB( int runNumber, int lumiBlockNr,
                  const std::vector<std::string>& grlnameVec=std::vector<std::string>(),
                  const std::vector<std::string>& brlnameVec=std::vector<std::string>() ) ;
  /// called for each event by GoodRunsListSelectorAlg to decide if the event should be passed
  bool passThisRunLB( const std::vector<std::string>& grlnameVec=std::vector<std::string>(), 
                      const std::vector<std::string>& brlnameVec=std::vector<std::string>() ) ;
  /// register grl/brl combination 
  bool registerGRLSelector(const std::string& name, const std::vector<std::string>& grlnameVec, const std::vector<std::string>& brlnameVec);
  /// get GRL selector registry
  const std::map< std::string, vvPair >& getGRLSelectorRegistry() { return m_registry; }

  /// get grl/brl collection
  const Root::TGRLCollection* getGRLCollection() const { return m_grlcollection; } 
  const Root::TGRLCollection* getBRLCollection() const { return m_brlcollection; }

 protected:

  bool fileExists(const char* fileName);

  std::vector<std::string> m_goodrunslistVec;
  std::vector<std::string> m_blackrunslistVec;

  Root::TGRLCollection* m_grlcollection;
  Root::TGRLCollection* m_brlcollection;

  Root::TGoodRunsListReader* m_reader;

  std::map< std::string,TFormula* > m_dqformula;

  int  m_boolop;
  bool m_passthrough;
  bool m_rejectanybrl;
  bool m_eventselectormode;

  std::map< std::string, vvPair > m_registry;

};

#endif

