# Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration

#==============================================================
# Job options file for the AFP_SiClusterTools package
#==============================================================

from AthenaConfiguration.ComponentAccumulator import ComponentAccumulator
from AthenaConfiguration.ComponentFactory import CompFactory
from AthenaConfiguration.Enums import Format
from IOVDbSvc.IOVDbSvcConfig import addFolders
from TrigEDMConfig.TriggerEDM import recordable


def AFP_SiClusterTools_Cfg(flags, kwargs={}):
        
        # original tool from Athena
        # clusterNeighbour = CompFactory.AFPSiClusterBasicNearestNeighbour("AFPSiClusterBasicNearestNeighbour")
        # it's also possible to get the same clustering tool as in AFPAnalysisToolbox
        clusterNeighbour = CompFactory.AFPSiClusterAllNeighbours("AFPSiClusterAllNeighbours", neighbourhoodType="X")
        
        rowColToLocal = CompFactory.AFPSiRowColToLocalCSTool("AFPSiRowColToLocalCSTool")
        
        acc = ComponentAccumulator()                                              
        if flags.Input.isMC:
                # if other tags are desired, they can be set also in postExec
                acc.merge(addFolders(flags, "/FWD/AFP/Align/Local<tag>AFPMCAlignLoc-ideal-01</tag>",  'FWD_OFL', className='CondAttrListCollection', db='OFLP200'))
                acc.merge(addFolders(flags, "/FWD/AFP/Align/Global<tag>AFPMCAlignGlob-ideal-01</tag>",'FWD_OFL', className='CondAttrListCollection', db='OFLP200'))
                
                siLocAlignTool  = CompFactory.getComp("AFP::SiLocAlignDBTool")("SiLocAlignDBTool",  loc_align_key="/FWD/AFP/Align/Local")
                siGlobAlignTool = CompFactory.getComp("AFP::SiGlobAlignDBTool")("SiGlobAlignDBTool",glob_align_key="/FWD/AFP/Align/Global")
        else:
                acc.merge(addFolders(flags, "/FWD/Onl/AFP/Align/Local<tag>AFPAlignLoc-03</tag>",  'FWD_ONL', className='CondAttrListCollection', db='CONDBR2'))
                acc.merge(addFolders(flags, "/FWD/Onl/AFP/Align/Global<tag>AFPAlignGlob-03</tag>",'FWD_ONL', className='CondAttrListCollection', db='CONDBR2'))
                
                siLocAlignTool  = CompFactory.getComp("AFP::SiLocAlignDBTool")("SiLocAlignDBTool",  loc_align_key="/FWD/Onl/AFP/Align/Local")
                siGlobAlignTool = CompFactory.getComp("AFP::SiGlobAlignDBTool")("SiGlobAlignDBTool",glob_align_key="/FWD/Onl/AFP/Align/Global")
        
        # prepare Si cluster reco
        clusterTool = CompFactory.AFPSiClusterTool("AFPSiClusterTool", clusterAlgTool=clusterNeighbour, rowColToLocalCSTool = rowColToLocal, siLocAlignDBTool=siLocAlignTool, siGlobAlignDBTool=siGlobAlignTool)
        
        if flags.Input.Format is Format.POOL:
                if "AFPSiHitContainer" not in flags.Input.Collections:
                        clusterTool.AFPSiHitsContainerName=""
                else:
                        from SGComps.SGInputLoaderConfig import SGInputLoaderCfg
                        acc.merge(SGInputLoaderCfg(flags,Load={('xAOD::AFPSiHitContainer','StoreGateSvc+AFPSiHitContainer')}))
        
        acc.addEventAlgo(CompFactory.AFPSiCluster("AFPSiCluster", clusterRecoTool = clusterTool, **kwargs))
        
        return acc


def AFP_SiClusterTools_HLT(flags):

        from AthenaConfiguration.ComponentAccumulator import ComponentAccumulator
        acc = ComponentAccumulator()
        acc.merge(AFP_SiClusterTools_Cfg(flags,{"AFPSiHitsClusterContainerKey": recordable("HLT_AFPSiHitsClusterContainer")}))
        
        
        AFP_SiCl = acc.getEventAlgo("AFPSiCluster")
        
        from AthenaMonitoringKernel.GenericMonitoringTool import GenericMonitoringTool

        monTool_AFP_SiClusterTool = GenericMonitoringTool(flags, "MonTool_AFP_SiClusterTool")
        monTool_AFP_SiClusterTool.defineHistogram( 'HitsSize', path='EXPERT', type='TH1F', title='SID hits size',xbins=50, xmin=0, xmax=50 )
        monTool_AFP_SiClusterTool.defineHistogram( 'ClusterSize', path='EXPERT', type='TH1F', title='SID cluster size',xbins=50, xmin=0, xmax=50 )
        AFP_SiCl.clusterRecoTool.MonTool = monTool_AFP_SiClusterTool

        return acc

