/*
  Copyright (C) 2002-2023 CERN for the benefit of the ATLAS collaboration
*/

#ifndef ZDCUTILS_ZDCWAVEFORMLTLINSTEP_H
#define ZDCUTILS_ZDCWAVEFORMLTLINSTEP_H

#include "ZDCWaveform.h"

//
// The waveform generated by a combined low-pass (tauRise) / high-pass (tauFall) filter with a linear "step" (tauLin) turn-on of the input
//   instead of a true step function.
//
//
class ZDCWaveformLTLinStep : virtual public ZDCWaveformBase
{
protected:
  double doEvaluate(double time) const override;

  virtual std::string name() const override {return "LTLinStep";}

public:
  ZDCWaveformLTLinStep() : 
    ZDCWaveformBase("default", 1, 6, std::vector<std::string>({"tauLin"}), std::vector<double>({1.0}))
  {  }

  ZDCWaveformLTLinStep(const std::string& tag, double initialTauRise, double initialTauFall, double initialTauLin) :
    ZDCWaveformBase(tag, initialTauRise, initialTauFall, std::vector<std::string>({"tauLin"}), std::vector<double>({initialTauLin}))
  {}

};

#endif
