/*
  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
*/

#ifndef XAOD_ANALYSIS

#include "EvgenProdTools/EvgenOTFTopUpSvc.h"

EvgenOTFTopUpSvc::EvgenOTFTopUpSvc(const std::string& name, ISvcLocator* pSvcLocator)
  : base_class(name, pSvcLocator)
  , m_nUsedSoFar(0)
  , m_newFileFlag(false)
  , m_nTotal(0)
  , m_nIterations(0)
{
  declareProperty("Efficiency",     m_efficiency=0.9,           "Estimate of Pythia/Herwig matching efficiency and filter efficiency");
  declareProperty("ExecDuringInit", m_execDuringInit=false,     "Execute OTF algorithm during intialize");
  declareProperty("NPerFile",       m_nPerFile=long(5000./0.9), "Number of events to make per file with OTF algorithm");
  declareProperty("NewFileName",    m_newFileName="events.lhe", "Please that the new OTF events went");
}

StatusCode EvgenOTFTopUpSvc::finalize() {
  ATH_MSG_INFO("Total on the fly generated events: " << m_nTotal << " over " << m_nIterations << " iterations.");
  return StatusCode::SUCCESS;
}

#endif
