# Copyright (C) 2002-2023 CERN for the benefit of the ATLAS collaboration

from AthenaCommon import Logging
from ..powheg_RES import PowhegRES

## Get handle to Athena logging
logger = Logging.logging.getLogger("PowhegControl")


class LQ_s_chan(PowhegRES):
    """! Default Powheg configuration for LeptoQuarks s-channel production.

    Create a configurable object with all applicable Powheg options.

    @author Andrej Saibel  <Andrej.Saibel@cern.ch>
    """

    def __init__(self, base_directory, **kwargs):
        """! Constructor: all process options are set here.

        @param base_directory: path to PowhegBox code.
        @param kwargs          dictionary of arguments from Generate_tf.
        """
        super(LQ_s_chan, self).__init__(base_directory, "LQ-s-chan", **kwargs)

        # Add all keywords for this process, overriding defaults if required
        self.add_keyword("bornktmin")
        self.add_keyword("bornonly")
        self.add_keyword("bornsmartsig", 0)
        self.add_keyword("bornsuppfact")
        self.add_keyword("bornzerodamp")
        self.add_keyword("bottommass")
        self.add_keyword("bottomthr")
        self.add_keyword("bottomthrpdf")
        self.add_keyword("btildeborn")
        self.add_keyword("btildecoll")
        self.add_keyword("btildereal")
        self.add_keyword("btildevirt")
        self.add_keyword("btlscalect")
        self.add_keyword("btlscalereal")
        self.add_keyword("BWgen",1)
        self.add_keyword("bwshape")
        self.add_keyword("charge",1)
        self.add_keyword("charmmass")
        self.add_keyword("charmthr")
        self.add_keyword("charmthrpdf")
        self.add_keyword("check_bad_st1")
        self.add_keyword("check_bad_st2")
        self.add_keyword("clobberlhe")
        self.add_keyword("colltest")
        self.add_keyword("compress_lhe")
        self.add_keyword("compress_upb")
        self.add_keyword("compute_rwgt")
        self.add_keyword("doublefsr")
        self.add_keyword("etacutlep")
        self.add_keyword("etacutjet")
        self.add_keyword("evenmaxrat",0)
        self.add_keyword("ew")
        self.add_keyword("facscfact", self.default_scales[0])
        self.add_keyword("fastbtlbound")
        self.add_keyword("fixedgrid")
        self.add_keyword("flg_debug")
        self.add_keyword("foldcsi")
        self.add_keyword("foldphi")
        self.add_keyword("foldy")
        self.add_keyword("fullrwgt")
        self.add_keyword("fullrwgtmode")
        self.add_keyword("gfermi")
        self.add_keyword("hdamp")
        self.add_keyword("hdecaymode")
        self.add_keyword("hdecaywidth")
        self.add_keyword("hfact", 104.16)
        self.add_keyword("hmass")
        self.add_keyword("hwidth")
        self.add_keyword("icsimax")
        self.add_keyword("ih1")
        self.add_keyword("ih2")
        self.add_keyword("itmx1", 2)
        self.add_keyword("itmx1rm")
        self.add_keyword("itmx2", 2)
        self.add_keyword("itmx2rm")
        self.add_keyword("iupperfsr")
        self.add_keyword("iupperisr")
        self.add_keyword("iymax")
        self.add_keyword("lhans1", self.default_PDFs)
        self.add_keyword("lhans2", self.default_PDFs)
        self.add_keyword("lhapdf6maxsets")
        self.add_keyword("lhrwgt_descr")
        self.add_keyword("lhrwgt_group_combine")
        self.add_keyword("lhrwgt_group_name")
        self.add_keyword("lhrwgt_id")
        self.add_keyword("LOevents")
        self.add_keyword("LQmasslow")
        self.add_keyword("LQmasshigh")
        self.add_keyword("manyseeds")
        self.add_keyword("maxseeds")
        self.add_keyword("minlo")
        self.add_keyword("mLQ",2000.)
        self.add_keyword("mLQcuthi")
        self.add_keyword("mLQcutlo")
        self.add_keyword("ncall1", 30000)
        self.add_keyword("ncall1rm")
        self.add_keyword("ncall2", 50000)
        self.add_keyword("ncall2rm")
        self.add_keyword("ncallfrominput")
        self.add_keyword("nubound", 50000)
        self.add_keyword("parallelstage")
        self.add_keyword("pdfreweight")
        self.add_keyword("ptcutlep")
        self.add_keyword("ptcutjet")
        self.add_keyword("rand1")
        self.add_keyword("rand2")
        self.add_keyword("recombination",1)
        self.add_keyword("renscfact", self.default_scales[1])
        self.add_keyword("runningscale")
        self.add_keyword("rwl_add")
        self.add_keyword("rwl_file")
        self.add_keyword("rwl_format_rwgt")
        self.add_keyword("rwl_group_events")
        self.add_keyword("smartsig")
        self.add_keyword("smear",0)
        self.add_keyword("softtest")
        self.add_keyword("stage2init")
        self.add_keyword("storeinfo_rwgt")
        self.add_keyword("storemintupb")
        self.add_keyword("testplots")
        self.add_keyword("testsuda")
        self.add_keyword("topmass")
        self.add_keyword("use-old-grid")
        self.add_keyword("use-old-ubound")
        self.add_keyword("widthLQ",0)
        self.add_keyword("withbtilde",1)
        self.add_keyword("withdamp")
        self.add_keyword("withremnants",1)
        self.add_keyword("withnegweights")
        self.add_keyword("withsubtr")
        self.add_keyword("xgriditeration")
        self.add_keyword("xupbound")
        self.add_keyword("y_1e",0)
        self.add_keyword("y_2e",0)
        self.add_keyword("y_3e",0)
        self.add_keyword("y_1m",0)
        self.add_keyword("y_2m",0)
        self.add_keyword("y_3m",0)
        self.add_keyword("y_1t",0)
        self.add_keyword("y_2t",0)
        self.add_keyword("y_3t",0)
        
        
