/*
  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
*/
#ifndef TRUTHUTILS_TRUTHCLASSES_H
#define TRUTHUTILS_TRUTHCLASSES_H

  // cppcheck-suppress syntaxError; cppcheck 2.16 bug (https://sourceforge.net/p/cppcheck/discussion/general/thread/44654d46c3)
  enum ParticleType : unsigned int {
    Unknown           =  0,
    UnknownElectron   =  1,
    IsoElectron       =  2,
    NonIsoElectron    =  3,
    BkgElectron       =  4,
    UnknownMuon       =  5,
    IsoMuon           =  6,
    NonIsoMuon        =  7,
    BkgMuon           =  8,
    UnknownTau        =  9,
    IsoTau            =  10,
    NonIsoTau         =  11,
    BkgTau            =  12,
    UnknownPhoton     =  13,
    IsoPhoton         =  14,
    NonIsoPhoton      =  15,
    BkgPhoton         =  16,
    Hadron            =  17,
    Neutrino          =  18,
    NuclFrag          =  19,
    NonPrimary        =  20,
    GenParticle       =  21,
    SUSYParticle      =  22,
    OtherBSMParticle  =  39,
    BBbarMesonPart    =  23,
    BottomMesonPart   =  24,
    CCbarMesonPart    =  25,
    CharmedMesonPart  =  26,
    BottomBaryonPart  =  27,
    CharmedBaryonPart =  28,
    StrangeBaryonPart =  29,
    LightBaryonPart   =  30,
    StrangeMesonPart  =  31,
    LightMesonPart    =  32,
    BJet              =  33,
    CJet              =  34,
    LJet              =  35,
    GJet              =  36,
    TauJet            =  37,
    UnknownJet        =  38
  };

  enum ParticleOrigin : unsigned int {
    NonDefined    = 0,

    SingleElec    = 1,
    SingleMuon    = 2,
    SinglePhot    = 3,
    SingleTau     = 4,

    PhotonConv    = 5,
    DalitzDec     = 6,
    ElMagProc     = 7,
    Mu            = 8,
    TauLep        = 9,
    top           = 10,
    QuarkWeakDec  = 11,
    WBoson        = 12,
    ZBoson        = 13,
    Higgs         = 14,
    HiggsMSSM     = 15,
    HeavyBoson    = 16,
    WBosonLRSM    = 17,
    NuREle        = 18,
    NuRMu         = 19,
    NuRTau        = 20,
    LQ            = 21,

    SUSY          = 22,
    OtherBSM      = 46,
    LightMeson    = 23,
    StrangeMeson  = 24,
    CharmedMeson  = 25,
    BottomMeson   = 26,
    CCbarMeson    = 27,
    JPsi          = 28,
    BBbarMeson    = 29,
    LightBaryon   = 30,
    StrangeBaryon = 31,
    CharmedBaryon = 32,
    BottomBaryon  = 33,
    PionDecay     = 34,
    KaonDecay     = 35,
    BremPhot      = 36,
    PromptPhot    = 37,
    UndrPhot      = 38,
    ISRPhot       = 39,
    FSRPhot       = 40,
    NucReact      = 41,
    PiZero        = 42,
    DiBoson       = 43,
    ZorHeavyBoson = 44,
    MultiBoson    = 47,
    QCD           = 45
  };

  enum ParticleOutCome : unsigned int {
    NonDefinedOutCome  =  0,
    UnknownOutCome     =  1,
    UnConverted        =  2,
    Converted          =  3,
    NonInteract        =  4,
    NuclInteraction    =  5,
    ElectrMagInter     =  6,
    DecaytoElectron    =  7,
    DecaytoMuon        =  8,
    OneProng           =  9,
    ThreeProng         = 10,
    FiveProng          = 11
  };



  struct ParticleDef {
    /** the vector of particle types */
      std::vector<std::string> sParticleType{
      "Unknown",
      "UnknownElectron",
      "IsoElectron",
      "NonIsoElectron",
      "BkgElectron",
      "UnknownMuon",
      "IsoMuon",
      "NonIsoMuon",
      "BkgMuon",
      "UnknownTau",
      "IsoTau",
      "NonIsoTau",
      "BkgTau",
      "UnknownPhoton",
      "IsoPhoton",
      "NonIsoPhoton",
      "BkgPhoton",
      "Hadron",
      "Neutrino",
      "NuclFrag",
      "NonPrimary",
      "GenParticle",
      "SUSYParticle",
      "BBbarMesonPart",
      "BottomMesonPart",
      "CCbarMesonPart",
      "CharmedMesonPart",
      "BottomBaryonPart",
      "CharmedBaryonPart",
      "StrangeBaryonPart",
      "LightBaryonPart",
      "StrangeMesonPart",
      "LightMesonPart",
      "BJet",
      "CJet",
      "LJet",
      "GJet",
      "TauJet",
      "UnknownJet",
      "OtherBSMParticle"};

      /** the vector of particle origin */
      std::vector<std::string> sParticleOrigin{
      "NonDefined",
      "SingleElec",
      "SingleMuon",
      "SinglePhot",
      "SingleTau",
      "PhotonConv",
      "DalitzDec",
      "ElMagProc",
      "Mu",
      "TauLep",
      "top",
      "QuarkWeakDec",
      "WBoson",
      "ZBoson",
      "Higgs",
      "HiggsMSSM",
      "WZMSSM",
      "WBosonLRSM",
      "NuREle",
      "NuRMu",
      "NuRTau",
      "LQ",
      "SUSY",
      "LightMeson",
      "StrangeMeson",
      "CharmedMeson",
      "BottomMeson",
      "CCbarMeson",
      "JPsi",
      "BBbarMeson",
      "LightBaryon",
      "StrangeBaryon",
      "CharmedBaryon",
      "BottomBaryon",
      "PionDecay",
      "KaonDecay",
      "BremPhot",
      "PromptPhot",
      "UndrPhot",
      "ISRPhot",
      "FSRPhot",
      "NucReact",
      "PiZero",
      "DiBoson",
      "ZorHeavyBoson",
      "QCD",
      "OtherBSM",
      "MultiBoson"};

      /** the vector of particle out come */
      std::vector<std::string> sParticleOutCome{
      "NonDefinedOutCome",
      "UnknownOutCome",
      "UnConverted",
      "Converted",
      "NonInteract",
      "NuclInteraction",
      "ElectrMagInter",
      "DecaytoElectron",
      "DecaytoMuon",
      "OneProng",
      "ThreeProng",
      "FiveProng"};
  };



#endif
