"""
Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
"""
import sys, os, smtplib

def EmailNotification(jobStatus):

    AtlasBuildBranch=os.environ.get("AtlasBuildBranch"  , "UNDEFINED")
    AthenaPlatform  =os.environ.get("Athena_PLATFORM"   , "UNDEFINED")
    AtlasRelease    =os.environ.get("ATLAS_RELEASE_BASE", "UNDEFINED")
    Atlasbuild      =os.environ.get("AtlasBuildStamp"   , "UNDEFINED")

    if AtlasBuildBranch != "24.0" and AtlasBuildBranch != "main":
        print("AtlasBuildBranch not 24.0 or main. Exiting.")
        sys.exit(0)


    mserver = "cernmx.cern.ch"
    mfrom   = "no-reply@cern.ch"
    mto     = ["atlas-trt-offline-shifts@cern.ch","atlas-trt-expert-shifters@cern.ch"]
    msubject = "ART test notification: TRT calibration Workflow for %s" % (AtlasBuildBranch)

    status="*SUCCEEDED*"
    if jobStatus.ACCU != 0 or jobStatus.MERGE != 0:
        status  = "*FAILED*\n"
        status += "\t- The TRT ACCU  transform %s.\n" % ("*is broken*" if jobStatus.ACCU else "works")
        status += "\t- The TRT MERGE transform %s." % ("*is broken*" if jobStatus.MERGE else "works")

    # assemble mail body
    mbody  = "Dear TRT expert/shifter\n\n" 
    mbody += "   This email is generated by the ART test InnerDetector/InDetCalibAlgs/TRT_CalibAlgs/test/test_TRTCalibration.sh \n\n"
    mbody += "   The test has %s\n\n" % (status)
    mbody += "   For %s\n\n" % (AtlasRelease)
    mbody += "   You can check the results in https://atlas-art-data.web.cern.ch/atlas-art-data/local-output/\n" 
    mbody += "   Outputs are in /eos/atlas/atlascerngroupdisk/data-art/local-output/%s/Athena/%s/%s/\n\n" % (AtlasBuildBranch,AthenaPlatform,Atlasbuild)      
    mbody += "Cheers\n" 
    mbody += "\tYour amazing TRT Calibration test" 
    
    fullmsg = "To: %s\nSubject: %s\n\n%s" % ("".join(("%s," % str(_mto_)) for _mto_ in mto ), msubject, mbody)

    print("Email body:\n")
    print(fullmsg)
    print("Email sent to:")

    try :
        con = smtplib.SMTP(mserver)
        print("\t- %s"% (mto))
        con.sendmail(mfrom, mto, fullmsg)
        con.quit()
    except OSError as e:
        print("ERROR: Failed sending email notification\n",e)
        exit(e.errno)

    
    
if __name__ == '__main__':
    
    import argparse
    parser = argparse.ArgumentParser(prog='python -m TRT_CalibAlgs.TRTCalibrationMessage',
                                   description="""Email notification for ART test - R-t TRT calibration.\n\n
                                   Example: python -m TRT_CalibAlgs.TRTCalibrationMessage --ACCU [status]...""")
    
    parser.add_argument('--ACCU'      ,type=int, help="Stores the status of the job")
    parser.add_argument('--MERGE'     ,type=int, help="Stores the status of the job")
    args = parser.parse_args()
    
    EmailNotification(args)

    sys.exit(0)

