/*
  Copyright (C) 2002-2025 CERN for the benefit of the ATLAS collaboration
*/

#include "SCT_MaterialManager.h"
#include "GeoModelKernel/GeoMaterial.h"
#include "GeoModelKernel/GeoElement.h"
#include "SCT_DataBase.h"
#include "RDBAccessSvc/IRDBRecordset.h"
#include "GaudiKernel/SystemOfUnits.h"

#include <iostream>

// Constructor 
SCT_MaterialManager::SCT_MaterialManager(SCT_DataBase* db):
  m_materialManager(std::make_unique<InDetMaterialManager>("SCT_MaterialManager", db->athenaComps()))
{
  // Make my material manager.
  m_materialManager->addWeightTable(db->weightTable(), "sct");
  m_materialManager->addScalingTable(db->scalingTable());
  
  loadMaterials();
  
  m_gasMaterial = m_materialManager->getMaterial("std::Air");
}

// Add materials not yet in the database 
void
SCT_MaterialManager::loadMaterials()
{
}

const GeoElement* 
SCT_MaterialManager::getElement(const std::string & elementName)
{
  return m_materialManager->getElement(elementName);
}

const GeoMaterial* 
SCT_MaterialManager::getMaterial(const std::string & materialName)
{
  return m_materialManager->getMaterial(materialName);
}

void
SCT_MaterialManager::addMaterial(GeoMaterial* material)
{
  return m_materialManager->addMaterial(material);
}

const GeoMaterial* 
SCT_MaterialManager::getMaterial(const std::string & originalMaterial, 
                                 double density,  
                                 const std::string & newName)
{
  
  return m_materialManager->getMaterial(originalMaterial, density, newName);
}

const GeoMaterial *
SCT_MaterialManager::getMaterialForVolume(const std::string & materialName, double volume)
{
  return m_materialManager->getMaterialForVolume(materialName, volume);
}



const GeoMaterial* 
SCT_MaterialManager::gasMaterial() const
{
  return m_gasMaterial;
}
