/*
  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
*/

#ifndef SCT_CLUSTERCONTAINERCNV_P2_H
#define SCT_CLUSTERCONTAINERCNV_P2_H

// SCT_DriftCircleContainerCnv_p2, T/P separation of SCT PRD
// author D.Costanzo <davide.costanzo@cern.ch>

#include "AthenaPoolCnvSvc/T_AthenaPoolTPConverter.h"

#include "InDetPrepRawData/SCT_ClusterContainer.h"
#include "InDetEventTPCnv/SCT_ClusterContainer_p2.h"

#include "InDetReadoutGeometry/SiDetectorElementCollection.h"
#include "StoreGate/ReadCondHandleKey.h"

class SCT_ID;
class StoreGateSvc;

class SCT_ClusterContainerCnv_p2 : public T_AthenaPoolTPCnvBase<InDet::SCT_ClusterContainer, InDet::SCT_ClusterContainer_p2>
{
 public:
  SCT_ClusterContainerCnv_p2() : m_sctId{nullptr}, m_SCTDetEleCollKey{"SCT_DetectorElementCollection"}, m_useDetectorElement{true}, m_isInitialized{false} {};
  
  virtual void transToPers(const InDet::SCT_ClusterContainer* transCont,
                           InDet::SCT_ClusterContainer_p2* persCont,
                           MsgStream &log) ;
  virtual void persToTrans(const InDet::SCT_ClusterContainer_p2* persCont,
                           InDet::SCT_ClusterContainer* transCont,
                           MsgStream &log) ;

  virtual InDet::SCT_ClusterContainer* createTransient(const InDet::SCT_ClusterContainer_p2* persObj, MsgStream& log);

  // Methods for test/SCT_ClusterContainerCnv_p2_test.cxx
  void setIdHelper(const SCT_ID* sct_id);
  void setUseDetectorElement(const bool useDetectorElement);

 private:
  const SCT_ID *m_sctId;
  SG::ReadCondHandleKey<InDetDD::SiDetectorElementCollection> m_SCTDetEleCollKey;
  bool m_useDetectorElement;
  bool m_isInitialized;
  StatusCode initialize(MsgStream &log);

};

#endif
