// -*- c++ -*-

/*
  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
*/

#ifndef INDETTRACKSELECTIONTOOL_TOOLTESTER_H
#define INDETTRACKSELECTIONTOOL_TOOLTESTER_H

// Gaudi/Athena include(s):
#include "AthenaBaseComps/AthReentrantAlgorithm.h"
#include "GaudiKernel/ToolHandle.h"

#include "xAODTracking/TrackParticleContainer.h"
#include "xAODTracking/VertexContainer.h"


namespace InDet {

  // forward declaration of tool
  class IInDetTrackSelectionTool;

   /// Simple algorithm for using the tools in Athena
   ///
   /// This is meant to be the "Athena equivalent" of the code put into
   /// util/InDetTrackSelectionToolTester.cxx.
   ///
   class ToolTester : public AthReentrantAlgorithm {

   public:
      /// Regular Algorithm constructor
      ToolTester( const std::string& name, ISvcLocator* svcLoc );

      /// Function initialising the algorithm
      virtual StatusCode initialize();
      /// Function executing the algorithm
      virtual StatusCode execute(const EventContext &ctx) const;

   private:
     /// StoreGate key for the track container to investigate
     SG::ReadHandleKey<xAOD::TrackParticleContainer> m_sgKey
     {this, "SGKey", "InDetTrackParticles"};

     SG::ReadHandleKey<xAOD::VertexContainer> m_vertexKey { this, "VertexContainer", "PrimaryVertices", 
	                                                    "reconstructed vertex container" };

     /// Connection to the selection tool
     ToolHandle< IInDetTrackSelectionTool > m_selTool
       {this, "TrackSelectionTool",
	"InDet::InDetTrackSelectionTool/TrackSelectionTool"};

   }; // class ToolTester

} // namespace InDet

#endif // INDETTRACKSELECTIONTOOL_TOOLTESTER_H
