/*
  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
*/

#ifndef INDETPHYSVALMONITORING_InDetPerfPlot_HITRESIDUAL
#define INDETPHYSVALMONITORING_InDetPerfPlot_HITRESIDUAL
/**
 * @file InDetPerfPlot_HitResidual.h
 * @author shaun roe
 **/


// std includes
#include <atomic>
#include <string>
#include <vector>
#include "TProfile.h"

// local includes

#include "InDetPlotBase.h"

// could be fwd declared?
#include "xAODTracking/TrackParticle.h"
#include "xAODTruth/TruthParticle.h"

// fwd declaration
class IToolSvc;
class IExtrapolator;


///class holding res plots for Inner Detector RTT Validation and implementing fill methods
class InDetPerfPlot_HitResidual: public InDetPlotBase {
public:
  InDetPerfPlot_HitResidual(InDetPlotBase* pParent, const std::string& dirName, bool isITk);

  void fill(const xAOD::TrackParticle& trkprt, float weight);
  ~InDetPerfPlot_HitResidual() {/** nop **/
  }

private:
  // enum copied from the hitDecorator tool in InDetPhysValMonitoring
  enum Subdetector {
    INVALID_DETECTOR=-1, L0PIXBARR, PIXEL, SCT, TRT, N_SUBDETECTORS
  };
  enum Region {
    INVALID_REGION=-1, BARREL, ENDCAP, N_REGIONS
  };

  void initializePlots();

  bool m_isITk;

  std::vector<std::vector<TH1*>> m_residualx_1hit = {N_SUBDETECTORS, {N_REGIONS, nullptr}}; // excludes TRT, DBM
  std::vector<std::vector<TH1*>> m_residualx_2ormorehits = {N_SUBDETECTORS, {N_REGIONS, nullptr}}; // excludes TRT, DBM
  std::vector<std::vector<TH1*>> m_residualx = {N_SUBDETECTORS, {N_REGIONS, nullptr}};
  std::vector<std::vector<TH2*>> m_residualx_eta = {N_SUBDETECTORS, {N_REGIONS, nullptr}};

  //
  std::vector<std::vector<TH1*>> m_residualy_1hit = {N_SUBDETECTORS, {N_REGIONS, nullptr}}; // excludes TRT, DBM
  std::vector<std::vector<TH1*>> m_residualy_2ormorehits = {N_SUBDETECTORS, {N_REGIONS, nullptr}}; // excludes TRT, DBM
  std::vector<std::vector<TH1*>> m_residualy = {N_SUBDETECTORS, {N_REGIONS, nullptr}};
  std::vector<std::vector<TH2*>> m_residualy_eta = {N_SUBDETECTORS, {N_REGIONS, nullptr}};
  //
  std::vector<std::vector<TH1*>> m_pullx = {N_SUBDETECTORS, {N_REGIONS, nullptr}};
  std::vector<std::vector<TH1*>> m_pully = {N_SUBDETECTORS, {N_REGIONS, nullptr}};
  std::vector<std::vector<TH2*>> m_pullx_eta = {N_SUBDETECTORS, {N_REGIONS, nullptr}};
  std::vector<std::vector<TH2*>> m_pully_eta = {N_SUBDETECTORS, {N_REGIONS, nullptr}};

  std::vector<std::vector<TH1*>> m_phiWidth = {N_SUBDETECTORS, {N_REGIONS, nullptr}};
  std::vector<std::vector<TH1*>> m_etaWidth = {N_SUBDETECTORS, {N_REGIONS, nullptr}};
  std::vector<std::vector<TH2*>> m_phiWidth_eta = {N_SUBDETECTORS, {N_REGIONS, nullptr}};
  std::vector<std::vector<TH2*>> m_etaWidth_eta = {N_SUBDETECTORS, {N_REGIONS, nullptr}};

  std::vector<TProfile*> m_phiWidthEta = {N_SUBDETECTORS, nullptr};
  std::vector<TProfile*> m_etaWidthEta = {N_SUBDETECTORS, nullptr};

  mutable std::atomic<int> m_warnCount{0};
};


#endif
