/*
  Copyright (C) 2002-2021 CERN for the benefit of the ATLAS collaboration
*/
/**
 * @file LArTPCnv/test/LArNoisyROSSummaryCnv_p3_test.cxx
 * @author scott snyder <snyder@bnl.gov>
 * @date Mar, 2016
 * @brief Tests for LArNoisyROSSummaryCnv_p3.
 */


#undef NDEBUG
#include "LArTPCnv/LArNoisyROSummaryCnv_p4.h"
#include "TestTools/leakcheck.h"
#include "GaudiKernel/MsgStream.h"
#include "CxxUtils/checker_macros.h"
#include <cassert>
#include <iostream>


void compare (const LArNoisyROSummary& p1,
              const LArNoisyROSummary& p2)
{
  assert (p1.get_noisy_febs() == p2.get_noisy_febs());
  assert (p1.get_noisy_preamps() == p2.get_noisy_preamps());
  assert (p1.BadFEBFlaggedPartitions() == p2.BadFEBFlaggedPartitions());
  assert (p1.BadFEB_WFlaggedPartitions() == p2.BadFEB_WFlaggedPartitions());
  assert (p1.SatMediumFlaggedPartitions() == p2.SatMediumFlaggedPartitions());
  assert (p1.SatTightFlaggedPartitions() == p2.SatTightFlaggedPartitions());
  assert (p1.MNBLooseFlaggedPartitions() == p2.MNBLooseFlaggedPartitions());
  assert (p1.MNBTightFlaggedPartitions() == p2.MNBTightFlaggedPartitions());
  assert (p1.get_MNBTight_febs() == p2.get_MNBTight_febs());
  assert (p1.get_MNBLoose_febs() == p2.get_MNBLoose_febs());
}


void testit (const LArNoisyROSummary& trans1)
{
  MsgStream log (0, "test");
  LArNoisyROSummaryCnv_p4 cnv;
  LArNoisyROSummary_p4 pers;
  cnv.transToPers (&trans1, &pers, log);
  LArNoisyROSummary trans2;
  cnv.persToTrans (&pers, &trans2, log);

  compare (trans1, trans2);
}


void test1 ATLAS_NOT_THREAD_SAFE ()
{
  std::cout << "test1\n";
  Athena_test::Leakcheck check;

  LArNoisyROSummary trans1;
  trans1.add_noisy_feb (HWIdentifier (0x1234));
  trans1.add_noisy_feb (HWIdentifier (0x1235));
  trans1.add_noisy_feb (HWIdentifier (0x1236));
  trans1.add_noisy_preamp (HWIdentifier (0x2134), 10);
  trans1.add_noisy_preamp (HWIdentifier (0x2135), 11);
  trans1.SetBadFEBFlaggedPartitions (0x12);
  trans1.SetBadFEB_WFlaggedPartitions (0x23);
  trans1.SetSatMediumFlaggedPartitions (0x34);
  trans1.SetSatTightFlaggedPartitions (0x45);
  trans1.SetMNBTightFlaggedPartitions (0x56);
  trans1.SetMNBLooseFlaggedPartitions (0x67);
  trans1.add_MNBTight_feb(HWIdentifier (0xF1234));
  trans1.add_MNBTight_feb(HWIdentifier (0xF1235));
  trans1.add_MNBLoose_feb(HWIdentifier (0xF4321));
  trans1.add_MNBLoose_feb(HWIdentifier (0xF4322));
    
  testit (trans1);
}


int main ATLAS_NOT_THREAD_SAFE ()
{
  test1();
  return 0;
}
