# Copyright (C) 2002-2023 CERN for the benefit of the ATLAS collaboration

from AthenaConfiguration.ComponentFactory import CompFactory 
from AthenaConfiguration.MainServicesConfig import MainServicesCfg

def LArPhysWavePredictionCfg(flags):

    #Get basic services and cond-algos
    from LArCalibProcessing.LArCalibBaseConfig import LArCalibBaseCfg,chanSelStr
    result=LArCalibBaseCfg(flags)

    from LArCalibProcessing.utils import FolderTagResolver
    FolderTagResolver._globalTag=flags.IOVDb.GlobalTag
    if flags.LArCalib.isSC:
       FolderTagResolver._defaultSuffix="-RUN2-UPD3-00"
    rs=FolderTagResolver()
    CaliWaveTag=rs.getFolderTag(flags.LArCalib.CaliWave.Folder)
    DetCellParamsTag=rs.getFolderTag(flags.LArCalib.DetCellParams.Folder)
    CaliPulseParamsTag=rs.getFolderTag(flags.LArCalib.CaliPulseParams.Folder)
    MphysOverMcalTag=rs.getFolderTag(flags.LArCalib.MphysOverMcal.Folder)
    PhysWaveTag=rs.getFolderTag(flags.LArCalib.PhysWave.Folder)
    del rs #Close database

    bcKey = "LArBadChannelSC" if flags.LArCalib.isSC else "LArBadChannel"     

    #Lots of special settings for HEC
    isHEC= (flags.LArCalib.Input.SubDet == "HEC")

    #"default" settings for CaliPulseParams (matter only for HEC)
    #In reality, we use only the first TdriftVector (no double-triangle)
    #copied from the old-cfg, mostly to maintain a record of the numbers. 
    HV = 2000
    if ( HV == 2000 ):
        TdriftVector  = [ 420  ,     469 ,     469 ,     469 ]
        TdriftVector2 = [ 420  ,     921 ,     921 ,     921 ]
        TdriftWeight2 = [   0. ,  0.0672 ,  0.0672 ,  0.0672 ]
    elif ( HV == 1600 ):
        TdriftVector  = [ 451.92 , 504.644 , 504.644 , 504.644 ]
        TdriftVector2 = [ 451.92 , 990.996 , 990.996 , 990.996 ]
        TdriftWeight2 = [   0.   ,  0.0672 ,  0.0672 ,  0.0672 ]


    #Retrieve inputs 
    from IOVDbSvc.IOVDbSvcConfig import addFolders
    result.merge(addFolders(flags,flags.LArCalib.CaliWave.Folder,detDb=flags.LArCalib.Input.Database, tag=CaliWaveTag, modifiers=chanSelStr(flags)))
    if flags.LArCalib.isSC:
       result.merge(addFolders(flags,"/LAR/ElecCalibOflSC/Tdrift/Computed",detDb="LAR_OFL",tag="LARElecCalibOflSCTdriftComputed-000"))
       result.merge(addFolders(flags,"/LAR/ElecCalibOflSC/PhysWaves/HECIdeal",detDb="LAR_OFL",tag="LARElecCalibOflSCPhysWavesHECIdeal-calib-02"))
       # in case main readout shape should be used:
       #result.merge(addFolders(flags,flags.LArCalib.FCALPhysWave.Folder,detDb="LAR_OFL",tag="LARElecCalibOflPhysWavesFCALFromTB-calib-01",modifiers="<key>FCALFromTB</key>"))
       # otherwise:
       result.merge(addFolders(flags,"/LAR/ElecCalibOflSC/PhysWaves/FCALmeasured",detDb="LAR_OFL",tag="LARElecCalibOflSCPhysWavesFCALmeasured-data-00",modifiers="<key>FCALFromData</key>"))
    else:   
       result.merge(addFolders(flags,"/LAR/ElecCalibOfl/Tdrift/Computed",detDb="LAR_OFL",tag="LARElecCalibOflTdriftComputed-calib-03"))
    

    if isHEC:
        result.merge(addFolders(flags,"/LAR/ElecCalibOfl/PhysWaves/HECIdeal",detDb="LAR_OFL",tag="LARElecCalibOflPhysWavesHECIdeal-calib-02"))
        if flags.LArCalib.isSC:
           result.merge(addFolders(flags,flags.LArCalib.CaliPulseParams.Folder,detDb=flags.LArCalib.Input.Database, tag=CaliPulseParamsTag))
           result.merge(addFolders(flags,flags.LArCalib.DetCellParams.Folder,detDb=flags.LArCalib.Input.Database, tag=DetCellParamsTag))
        else:    
           result.merge(addFolders(flags,flags.LArCalib.CaliPulseParams.Folder,detDb="LAR_OFL", tag=CaliPulseParamsTag))
    else:
        result.merge(addFolders(flags,flags.LArCalib.CaliPulseParams.Folder,detDb=flags.LArCalib.Input.Database, tag=CaliPulseParamsTag))
        result.merge(addFolders(flags,flags.LArCalib.DetCellParams.Folder,detDb=flags.LArCalib.Input.Database, tag=DetCellParamsTag))

    LArPhysWavePredictor = CompFactory.LArPhysWavePredictor( "LArPhysWavePredictor" )
    LArPhysWavePredictor.ProblemsToMask= ["deadCalib","deadReadout","deadPhys","almostDead","short"]
    LArPhysWavePredictor.TestMode      = False
    LArPhysWavePredictor.isSC          = flags.LArCalib.isSC
    LArPhysWavePredictor.KeyCaliList   =  [ "LArCaliWave" ]
    LArPhysWavePredictor.UseCaliPulseParamsFromJO = isHEC
    LArPhysWavePredictor.UseDetCellParamsFromJO   = isHEC
    LArPhysWavePredictor.UseTdriftFromJO          = isHEC
    LArPhysWavePredictor.Tdrift	                  = TdriftVector
    LArPhysWavePredictor.UseDoubleTriangle        = False
    LArPhysWavePredictor.Tdrift2	          = TdriftVector2
    LArPhysWavePredictor.WeightTriangle2          = TdriftWeight2
    LArPhysWavePredictor.UseTimeShiftFromJO       = True
    LArPhysWavePredictor.GroupingType             = flags.LArCalib.GroupingType
    LArPhysWavePredictor.NormalizeCali	          = not isHEC
    LArPhysWavePredictor.KeyMphysMcali	          = "LArMphysOverMcal"
    LArPhysWavePredictor.DumpMphysMcali           = False # set to True to dump on a ASCII file
    LArPhysWavePredictor.KeyPhys                  = "LArPhysWave"
    LArPhysWavePredictor.isHEC                    = isHEC
    LArPhysWavePredictor.BadChanKey               = bcKey

    if flags.LArCalib.isSC:
       LArPhysWavePredictor.KeyFcal               = "FCALFromData"

    result.addEventAlgo(LArPhysWavePredictor)
    
    if (flags.LArCalib.isSC or flags.LArCalib.Input.SubDet == "HEC"):
        LArPhysWaveHECTool=CompFactory.LArPhysWaveHECTool("LArPhysWaveHECTool")
        LArPhysWaveHECTool.NormalizeCali     = False  
        LArPhysWaveHECTool.TimeOriginShift   = False
        LArPhysWaveHECTool.SubtractBaseline  = False
        LArPhysWaveHECTool.isSC              = flags.LArCalib.isSC
        result.addPublicTool(LArPhysWaveHECTool)


    if flags.LArCalib.isSC or flags.LArCalib.Input.SubDet != "HEC":
        LArPhysWaveTool=CompFactory.LArPhysWaveTool("LArPhysWaveTool")
        LArPhysWaveTool.NormalizeCali     = False # this is taken care by LArPhysWavePredictor
        LArPhysWaveTool.TimeOriginShift   = False
        LArPhysWaveTool.SubtractBaseline  = False
        LArPhysWaveTool.InjPointCorrLayer = [ 1, 1, 1, 1 ]
        LArPhysWaveTool.InjPointUseTauR   = [ 1, 1, 1, 1 ]
        result.addPublicTool(LArPhysWaveTool)
   
 
    rootfile=flags.LArCalib.Output.ROOTFile
    if rootfile != "":
      LArPhysWaves2Ntuple              = CompFactory.LArPhysWaves2Ntuple("LArPhysWaves2Ntuple")
      LArPhysWaves2Ntuple.NtupleName   = "PHYSWAVE" 
      LArPhysWaves2Ntuple.AddFEBTempInfo   = False  
      LArPhysWaves2Ntuple.KeyList      = [ "LArPhysWave"  ]
      LArPhysWaves2Ntuple.isSC = flags.LArCalib.isSC
      LArPhysWaves2Ntuple.AddCalib = True
      LArPhysWaves2Ntuple.BadChanKey = bcKey
      result.addEventAlgo(LArPhysWaves2Ntuple)

      LArMphysOverMcal2Ntuple                = CompFactory.LArMphysOverMcal2Ntuple( "LArMphysOverMcal2Ntuple" )
      LArMphysOverMcal2Ntuple.ContainerKey   = "LArMphysOverMcal"
      LArMphysOverMcal2Ntuple.AddFEBTempInfo   = False
      LArMphysOverMcal2Ntuple.isSC = flags.LArCalib.isSC
      LArMphysOverMcal2Ntuple.BadChanKey = bcKey
      result.addEventAlgo(LArMphysOverMcal2Ntuple)

      import os
      if os.path.exists(rootfile):
          os.remove(rootfile)
      result.addService(CompFactory.NTupleSvc(Output = [ "FILE1 DATAFILE='"+rootfile+"' OPT='NEW'" ]))
      result.setAppProperty("HistogramPersistency","ROOT")
    pass # end if ROOT ntuple writing
    

    from RegistrationServices.OutputConditionsAlgConfig import OutputConditionsAlgCfg
    result.merge(OutputConditionsAlgCfg(flags,
                                        outputFile=flags.LArCalib.Output.POOLFile,
                                        ObjectList=["LArPhysWaveContainer#LArPhysWave#"+flags.LArCalib.PhysWave.Folder,
                                                    "LArMphysOverMcalComplete#LArMphysOverMcal#"+flags.LArCalib.MphysOverMcal.Folder,],
                                        IOVTagList=[PhysWaveTag,MphysOverMcalTag],
                                        Run1=flags.LArCalib.IOVStart,
                                        Run2=flags.LArCalib.IOVEnd
                                    ))

    #RegistrationSvc    
    result.addService(CompFactory.IOVRegistrationSvc(RecreateFolders = False))
    result.getService("IOVDbSvc").DBInstance=""

    #MC Event selector since we have no input data file 
    from McEventSelector.McEventSelectorConfig import McEventSelectorCfg
    result.merge(McEventSelectorCfg(flags,
                                    RunNumber         = flags.LArCalib.Input.RunNumbers[0],
                                    EventsPerRun      = 1,
                                    FirstEvent	      = 1,
                                    InitialTimeStamp  = 0,
                                    TimeStampInterval = 1))

    from PerfMonComps.PerfMonCompsConfig import PerfMonMTSvcCfg
    result.merge(PerfMonMTSvcCfg(flags))

    return result



if __name__ == "__main__":

    import sys
    from AthenaConfiguration.AllConfigFlags import initConfigFlags
    ConfigFlags=initConfigFlags()
    from LArCalibProcessing.LArCalibConfigFlags import addLArCalibFlags
    addLArCalibFlags(ConfigFlags)

    ConfigFlags.Input.Files=[]
    ConfigFlags.LArCalib.Input.RunNumbers=[401351,]
    ConfigFlags.LArCalib.Input.Database="/home/wlampl/calibTest/00400939_00400943_00400945_Barrel-EMB-EMEC_HIGH_40_21.0.20_1/poolFiles/myDB200_00400939_00400943_00400945_EB-EMBA_one.db_Delay"
    ConfigFlags.LArCalib.Input.SubDet="EM"
    ConfigFlags.LArCalib.BadChannelDB="/home/wlampl/calibTest/00400939_00400943_00400945_Barrel-EMB-EMEC_HIGH_40_21.0.20_1/poolFiles/SnapshotBadChannel_00400939_00400943_00400945_EB-EMBA.db"
    ConfigFlags.LArCalib.BadChannelTag="-RUN2-UPD3-00"
    ConfigFlags.LArCalib.Output.ROOTFile="physwave.root"
    ConfigFlags.IOVDb.DatabaseInstance="CONDBR2"
    ConfigFlags.IOVDb.DBConnection="sqlite://;schema=output.sqlite;dbname=CONDBR2"
    ConfigFlags.IOVDb.GlobalTag="LARCALIB-RUN2-02"
    from AthenaConfiguration.TestDefaults import defaultGeometryTags
    ConfigFlags.GeoModel.AtlasVersion=defaultGeometryTags.RUN3
    ConfigFlags.IOVDb.DatabaseInstance="CONDBR2"
    ConfigFlags.LAr.doAlign=False
    ConfigFlags.Input.RunNumbers=ConfigFlags.LArCalib.Input.RunNumbers

    #ConfigFlags.Exec.OutputLevel=1
    ConfigFlags.fillFromArgs()
    ConfigFlags.lock()
    cfg=MainServicesCfg(ConfigFlags)
    cfg.merge(LArPhysWavePredictionCfg(ConfigFlags))

    print("Start running...")
    sys.exit(cfg.run(1).isFailure())
    
