/*
  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
*/

#ifndef MUONBYTESTREAMRPCRDODECODER_H
#define MUONBYTESTREAMRPCRDODECODER_H

#include <inttypes.h>

#include <string>
#include <vector>

#include "AthenaBaseComps/AthAlgTool.h"
#include "GaudiKernel/ServiceHandle.h"
#include "MuonIdHelpers/IMuonIdHelperSvc.h"
#include "MuonRPC_CnvTools/IRPC_RDO_Decoder.h"
#include "RPC_CondCabling/RpcCablingCondData.h"

// Decoder class for conversion from RPC RDOs to RPC digits
namespace Muon {

    class RpcRDO_Decoder : public extends<AthAlgTool, IRPC_RDO_Decoder> {
    public:
        RpcRDO_Decoder(const std::string& type, const std::string& name, const IInterface* parent);
        ~RpcRDO_Decoder() = default;

        virtual StatusCode initialize() override;

        virtual std::vector<std::unique_ptr<RpcDigit>> getDigit(const RpcFiredChannel* fChan, uint16_t& sectorID, uint16_t& padId, uint16_t& cmaId,
                                                 const RpcCablingCondData* rpcCab) const override;

        virtual std::vector<Identifier> getOfflineData(const RpcFiredChannel* fChan, uint16_t& sectorID, uint16_t& padId, uint16_t& cmaId,
                                                        double& time, const RpcCablingCondData* rpcCab) const override;

    private:
      ServiceHandle<Muon::IMuonIdHelperSvc> m_idHelperSvc{this, "MuonIdHelperSvc", "Muon::MuonIdHelperSvc/MuonIdHelperSvc"};
      Gaudi::Property<int> m_bczero { this, "BCZERO", 3, "Nominal BC for RPC readout"};

    };

}  // namespace Muon

#endif  // MUONBYTESTREAMRPCRDODECODER_H
