/*
  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
*/

/********************************************************
 Class def for MuonGeoModel DblQ00/ACUT
 *******************************************************/

 //  author: S Spagnolo
 // entered: 07/28/04
 // comment: CUT OF STATION

#ifndef DBLQ00_ACUT_H
#define DBLQ00_ACUT_H
#include <string>
#include <vector>


class IRDBAccessSvc;


namespace MuonGM {
class DblQ00Acut {
public:
    DblQ00Acut() = default;
    DblQ00Acut & operator=(const DblQ00Acut &right) = delete;
    DblQ00Acut(const DblQ00Acut&) = delete;

    ~DblQ00Acut() = default;
    DblQ00Acut(IRDBAccessSvc *pAccessSvc, const std::string & GeoTag="", const std::string & GeoNode="");

    // data members for DblQ00/ACUT fields
    struct ACUT {
        int version{0}; // VERSION
        int i{0}; // INDEX
        int icut{0}; // CUT-OUT INDEX
        int n{0}; // NUMBER OF SUB-CUTS IN THE STATION
    };
    
    const ACUT* data() const { return m_d.data(); };
    unsigned int size() const { return m_nObj; };
    const char* getName() const { return "ACUT"; };
    const char* getDirName() const { return "DblQ00"; };
    const char* getObjName() const { return "ACUT"; };
    
private:
    std::vector<ACUT> m_d;
    unsigned int m_nObj{}; // > 1 if array; 0 if error in retrieve.
};
} // end of MuonGM namespace

#endif // DBLQ00_ACUT_H

