/*
  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
*/

/***************************************************************************
 properties of a plane based strip detector with equidistant parallel strips
 -----------------------------------------
***************************************************************************/

#ifndef MUONREADOUTGEOMETRY_MUONSTRIPDESIGN_H
#define MUONREADOUTGEOMETRY_MUONSTRIPDESIGN_H
#include "GeoPrimitives/GeoPrimitives.h"

#include <algorithm>
#include <cstdint>
namespace MuonGM {

    struct MuonStripDesign {
    public:
        int nstrips{0};
        double stripPitch{0.};
        double invStripPitch{0.};
        double stripLength{0.};
        double stripWidth;
        double readoutLocY{0.};
        double signY{0.};
        Amg::Vector2D firstStripPos{Amg::Vector2D::Zero()};

        /** distance to readout */
        double distanceToReadout(const Amg::Vector2D& pos) const;
        double distanceToReadout(double locY) const;

        /** calculate local strip number, range 1=nstrips like identifiers. Returns -1 if out of range */
        int stripNumber(const Amg::Vector2D& pos) const;
        int stripNumber(double locX) const;

        /** calculate local strip position for a given strip number */
        bool stripPosition(int strip, Amg::Vector2D& pos) const;
    };

    inline double MuonStripDesign::distanceToReadout(const Amg::Vector2D& pos) const { return distanceToReadout(pos.y()); }

    inline double MuonStripDesign::distanceToReadout(double locY) const {
        return std::clamp(locY - readoutLocY, 0., stripLength);
    }

    inline int MuonStripDesign::stripNumber(const Amg::Vector2D& pos) const { return stripNumber(pos.x()); }

    inline int MuonStripDesign::stripNumber(double locX) const {
        int st = (locX - firstStripPos.x()) * invStripPitch + 1.5;
        if (st < 1) return -1;
        if (st > nstrips) return -1;
        return st;
    }

    inline bool MuonStripDesign::stripPosition(int st, Amg::Vector2D& pos) const {
        if (st < 1 || st > nstrips) return false;
        pos[0] = firstStripPos.x() + stripPitch * (st - 1);
        pos[1] = firstStripPos.y();
        return true;
    }

}  // namespace MuonGM
#endif  // MUONREADOUTGEOMETRY_MUONSTRIPDESIGN_H
