/*
  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
*/

#ifndef MUONGEOMODELR4_MUONGEOUTILITYTOOL_H
#define MUONGEOMODELR4_MUONGEOUTILITYTOOL_H

#include <CxxUtils/checker_macros.h>
#include <GeoModelInterfaces/IGeoDbTagSvc.h>
#include <GeoModelUtilities/GeoModelTool.h>
#include <MuonGeoModelR4/IMuonGeoUtilityTool.h>
#include <AthenaBaseComps/AthAlgTool.h>
#include <GeoModelKernel/GeoSimplePolygonBrep.h>


namespace MuonGMR4 {

class MuonGeoUtilityTool final :  public extends<AthAlgTool, IMuonGeoUtilityTool>{

   public:
    // Constructor
    using base_class::base_class;

    // Destructor
    virtual ~MuonGeoUtilityTool() override final;

    const GeoAlignableTransform* findAlignableTransform(const PVConstLink& physVol) const override final;

    const GeoShape* extractShape(const PVConstLink& physVol) const override final;
    const GeoShape* extractShape(const GeoShape* inShape) const override final;
    
    // Navigates through the volume to find the shifts / rotations etc.
    Amg::Transform3D extractShifts(const PVConstLink& physVol) const override final;
    Amg::Transform3D extractShifts(const GeoShape* inShape) const override final;


      
    std::vector<physVolWithTrans> findAllLeafNodesByName(const PVConstLink& physVol, const std::string& volumeName) const override final;

    std::vector<const GeoShape*> getComponents(const GeoShape* booleanShape) const override final;
    /// Dumps the shape to string
    std::string dumpShape(const GeoShape* inShape) const override final;

    std::string dumpVolume(const PVConstLink& physVol) const override final;

    /// Transforms the vertices of the Polygon shape into a std::vector consisting of Amg::Vector2D objects
    std::vector<Amg::Vector2D> polygonEdges(const GeoSimplePolygonBrep& polygon) const override;

    std::vector<Amg::Vector3D> shapeEdges(const GeoShape* shape,
                                          const Amg::Transform3D& refTrf) const override;

   private:

};
}  // namespace MuonGMR4
#endif
