// Dear emacs, this is -*- c++ -*-
//
// Copyright (C) 2002-2025 CERN for the benefit of the ATLAS collaboration
//
#ifndef TRACKINGANALYSISALGORITHMS_VERTEXSELECTIONALG_H
#define TRACKINGANALYSISALGORITHMS_VERTEXSELECTIONALG_H

// Framework include(s):
#include <AnaAlgorithm/AnaReentrantAlgorithm.h>
#include <EventBookkeeperTools/FilterReporterParams.h>
#include <AsgTools/PropertyWrapper.h>
#include <AsgDataHandles/ReadHandleKey.h>
#include <AsgDataHandles/ReadHandle.h>

// EDM include(s):
#include "xAODTracking/VertexContainer.h"

// System include(s):
#include <string>

namespace CP {

   /// Algorithm meant to select events with "some" vertex requirements
   ///
   /// This algorithm is meant to be used to pose vertex requirements for the
   /// analysed event. Most commonly requiring at least one primary vertex with
   /// some number of track particles associated to it.
   ///
   /// @author Attila Krasznahorkay <Attila.Krasznahorkay@cern.ch>
   ///
   class VertexSelectionAlg final : public EL::AnaReentrantAlgorithm {

   public:
      /// Algorithm constructor
     using EL::AnaReentrantAlgorithm::AnaReentrantAlgorithm;

      /// @name Function(s) inherited from @c EL::AnaReentrantAlgorithm
      /// @{

      /// Function initialising the algorithm
      virtual StatusCode initialize() override;

      /// Function executing the algorithm
      virtual StatusCode execute(const EventContext &ctx) const override;

      /// Function finalize the algorithm
      virtual StatusCode finalize() override;

      /// @}

   private:
      /// @name Algorithm properties
      /// @{

      /// Event store key of the vertex container
     SG::ReadHandleKey<xAOD::VertexContainer> m_vertexKey {this, "VertexContainer", "PrimaryVertices", "Vertex container to check"};
      /// Number of vertices required in the event
     Gaudi::Property<unsigned> m_minVertices {this, "MinVertices", 1, "Minimum number of vertices required"};
      /// Number of track particles required per vertex
     Gaudi::Property<unsigned> m_minTracks {this, "MinTracks", 0, "Minimum number of track particles required per vertex"};

      FilterReporterParams m_filterParams {this, "VertexSelection", "vertex selection"};

      /// @}

   }; // class VertexSelectionAlg

} // namespace CP

#endif // TRACKINGANALYSISALGORITHMS_VERTEXSELECTIONALG_H
