/*
  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
*/

#ifndef JIVEXML_COMPOSITEPARTICLERETRIEVER_H
#define JIVEXML_COMPOSITEPARTICLERETRIEVER_H

#include <string>


#include "JiveXML/IDataRetriever.h"
#include "AthenaBaseComps/AthAlgTool.h"
#include "JiveXML/DataType.h" //DataMap typedef

class CompositeParticleContainer;

namespace JiveXML{
  
  /**
   * @class CompositeParticleRetriever
   * @brief Retrieves all @c CompositeParticle @c objects (AllObjects)
   *
   *  - @b Properties
   *    - StoreGateKey: First collection to be retrieved, displayed
   *      in Atlantis without switching. All other collections are 
   *      also retrieved.
   *
   *  - @b Retrieved @b Data
   *    - Usual four-vectors: phi, eta, et
   */
  class CompositeParticleRetriever : virtual public IDataRetriever,
                                   public AthAlgTool {
    
    public:
      
      /// Standard Constructor
      CompositeParticleRetriever(const std::string& type,const std::string& name,const IInterface* parent);
      
      /// Retrieve all the data
      virtual StatusCode retrieve(ToolHandle<IFormatTool> &FormatTool); 
      const DataMap getData(const CompositeParticleContainer*);
    
      /// Return the name of the data type
      virtual std::string dataTypeName() const { return m_typeName; };

    private:
      ///The data type that is generated by this retriever
      const std::string m_typeName;

      std::string m_sgKey;
  };
}
#endif
