/*
  Copyright (C) 2002-2025 CERN for the benefit of the ATLAS collaboration
*/

#ifndef JIVEXML_xAODMUONRETRIEVER_H
#define JIVEXML_xAODMUONRETRIEVER_H

#include <string>
#include <vector>
#include <map>

#include "JiveXML/IDataRetriever.h"
#include "AthenaBaseComps/AthAlgTool.h"
#include "xAODMuon/MuonContainer.h"

namespace JiveXML{

  /**
   * @class xAODMuonRetriever
   * @brief Retrieves all @c Muon @c objects (MuonAODCollection etc.)
   *
   *  - @b Properties
   *    - PriorityMuonCollection: First collection to be retrieved, displayed
   *      in Atlantis without switching. All other collections are
   *      also retrieved.
   *    - OtherMuonCollections
   *    - DoWriteHLT
   *    - DoWriteAllCollections
   *
   *  - @b Retrieved @b Data
   *    - Usual four-vectors: phi, eta, et etc.
   *    - Associations for clusters and tracks via ElementLink: key/index scheme
   */
  class xAODMuonRetriever : virtual public IDataRetriever,
			    public AthAlgTool {

  public:

    /// Standard Constructor
    xAODMuonRetriever(const std::string& type,const std::string& name,const IInterface* parent);

    virtual StatusCode retrieve(ToolHandle<IFormatTool> &FormatTool);
    /// Puts the variables into a DataMap
    const DataMap getData(const xAOD::MuonContainer*);
    /// Gets the StoreGate keys for the desired containers
    const std::vector<std::string> getKeys();
    /// Return the name of the data type that is generated by this retriever
    virtual std::string dataTypeName() const { return m_typeName; };

  private:

    /// The data type that is generated by this retriever
    const std::string m_typeName = "Muon";

    Gaudi::Property<bool> m_doWriteHLT {this, "DoWriteHLT", false, "Write out other collections that have HLT in the name"};
    Gaudi::Property<bool> m_doWriteAllCollections {this, "DoWriteAllCollections", false, "Write out all Cluster collections"};
    Gaudi::Property<std::vector<std::string>> m_otherKeys {this, "OtherMuonCollections", {}, "Other collections to be retrieved. If DoWriteAllCollections is set to true all available Muon collections will be retrieved"};
    Gaudi::Property<std::string> m_priorityKey {this,"PriorityMuonCollection","Muons", "Name of the priority Muon container that will be written out first"};

  };
}
#endif
