/*
  Copyright (C) 2002-2025 CERN for the benefit of the ATLAS collaboration
*/

#ifndef JIVEXML_XAODTRACKPARTICLERETRIEVER_H
#define JIVEXML_XAODTRACKPARTICLERETRIEVER_H

#include <string>
#include <vector>
#include <map>

#include "JiveXML/IDataRetriever.h"
#include "AthenaBaseComps/AthAlgTool.h"
#include "xAODTracking/TrackParticleContainer.h"

namespace JiveXML{

  /**
   * @class xAODTrackParticleRetriever
   * @brief Retrieves all @c TrackParticle @c objects (TrackParticleAODCollection etc.)
   *
   *  - @b Properties
   *    - PriorityTrackParticleCollection: First collection to be retrieved, displayed
   *      in Atlantis without switching. All other collections are
   *      also retrieved.
   *    - OtherTrackParticleCollections
   *    - DoWriteHLT
   *    - DoWriteAllCollections
   *
   *  - @b Retrieved @b Data
   *    - Usual four-vectors: phi, eta, et etc.
   *    - Associations for clusters and tracks via ElementLink: key/index scheme
   */
  class xAODTrackParticleRetriever : virtual public IDataRetriever,
				     public AthAlgTool {

  public:

    /// Standard Constructor
    xAODTrackParticleRetriever(const std::string& type,const std::string& name,const IInterface* parent);

    virtual StatusCode retrieve(ToolHandle<IFormatTool> &FormatTool);
    /// Puts the variables into a DataMap
    const DataMap getData(const xAOD::TrackParticleContainer*);
    /// Gets the StoreGate keys for the desired containers
    const std::vector<std::string> getKeys();
    /// Return the name of the data type that is generated by this retriever
    virtual std::string dataTypeName() const { return m_typeName; };

  private:

    /// The data type that is generated by this retriever
    const std::string m_typeName = "Track";

    Gaudi::Property<bool> m_doWriteHLT {this, "DoWriteHLT", false, "Write out other collections that have HLT in the name"};
    Gaudi::Property<bool> m_doWriteAllCollections {this, "DoWriteAllCollections", false, "Write out all TrackParticle collections"};
    Gaudi::Property<std::vector<std::string>> m_otherKeys {this, "OtherTrackParticleCollections", {"InDetLargeD0TrackParticles", "CombinedMuonTrackParticles", "GSFTrackParticles"}, "Other collections to be retrieved. If DoWriteAllCollections is set to true all available TrackParticle collections will be retrieved"};
    Gaudi::Property<std::string> m_priorityKey {this,"PriorityTrackParticleCollection","InDetTrackParticles", "Name of the priority TrackParticle container that will be written out first"};

  };
}
#endif
