/*
  Copyright (C) 2002-2023 CERN for the benefit of the ATLAS collaboration
*/

// Dear emacs, this is -*-c++-*-

#ifndef ELECTRONDNNCALCULATOR_H
#define ELECTRONDNNCALCULATOR_H

// This include is needed at the top before any includes regarding lwtnn
// since it includes Eigen in a specific way which causes compilation errors
// if not included before lwtnn
#include "EventPrimitives/EventPrimitives.h"

#include "AsgMessaging/AsgMessagingForward.h"
#include "ElectronPhotonSelectorTools/AsgElectronSelectorTool.h"
#include "TTree.h"
#include <vector>
#include <string>
#include "lwtnn/generic/FastGraph.hh"


class ElectronDNNCalculator : public asg::AsgMessagingForward
{
public:
  /** Constructor of the class*/
  ElectronDNNCalculator( AsgElectronSelectorTool* owner,
                         const std::string& modelFileName,
                         const std::string& quantileFileName,
                         const std::vector<std::string>& variablesName,
                         const bool multiClass);

  /** Standard destructor*/
  ~ElectronDNNCalculator() {};

  /** Get the prediction of the DNN model*/
  Eigen::Matrix<float, -1, 1> calculate( const std::vector<double>& ) const;

private:
  /** transform the input variables according to a given QuantileTransformer.*/
  double transformInput( const std::vector<double>& quantiles, double value ) const;
  /** read the bins and values of the QuantileTransformer to transform the input variables.*/
  int readQuantileTransformer( TTree* tree );

  /// DNN interface via lwtnn
  std::unique_ptr<lwt::generic::FastGraph<float>> m_graph = 0;

  /// Quantile values for each variable that needs to be transformed with the QuantileTransformer
  std::vector<std::vector<double>> m_quantiles;
  /// Reference values for the QuantileTransformer. Basically just equidistant bins between 0 and 1.
  std::vector<double> m_references;
  /// Whether the used model is a multiclass model or not.
  bool m_multiClass;
  /// Model variables
  std::vector<std::string> m_variables;
  uint m_var_size;
};

#endif
