/*
  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
*/

#ifndef GEO2G4_VolumeBuilder_H
#define GEO2G4_VolumeBuilder_H

#include "G4LogicalVolume.hh"
#include "G4VPhysicalVolume.hh"

#include "GeoModelUtilities/GeoOpticalPhysVol.h"

#include <string>
#include <map>
#include <functional> //std::less

typedef std::map< const GeoOpticalPhysVol*, G4VPhysicalVolume*,std::less< const GeoOpticalPhysVol*> > OpticalVolumesMap;

class VolumeBuilder
{
 public:
  VolumeBuilder(const std::string& k): m_paramOn(false), m_key(k)
  {}

  virtual ~VolumeBuilder()
  {}

  const std::string & GetKey() const {return m_key;}

  // flag controlling Parameterization to Parameterization translation
  void SetParam(bool flag){m_paramOn = flag;}
  bool GetParam() const {return m_paramOn;}

  virtual G4LogicalVolume* Build(PVConstLink pv, OpticalVolumesMap* optical_volumes = 0) = 0;

 protected:
  bool m_paramOn;

 private:
  std::string m_key;
};
#endif
