/*
  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
*/

#ifndef TRKTOOLINTERFACES_IDETAILEDTRACKTRUTHBUILDER_H
#define TRKTOOLINTERFACES_IDETAILEDTRACKTRUTHBUILDER_H

#include "GaudiKernel/IAlgTool.h"

#include "TrkTrack/TrackCollection.h" /* forward declaring the typedef would be ugly.. */
#include <vector>

// Forard declarations of types.
class PRD_MultiTruthCollection;
class DetailedTrackTruthCollection;

namespace Trk {

  /** @brief Provides interface for tool to return a "detailed" track truth map.

      @author Andrei Gaponenko <agaponenko@lbl.gov>  */
  class IDetailedTrackTruthBuilder : virtual public IAlgTool {
  public:

    /** The main tool method.  Fills a pre-existing
     * DetailedTrackTruthCollection pointed to by output with data for
     * the tracks, using the prdTruth collections.  pdrTruth is
     * allowed to contain null pointers.  Each non-null pointer must
     * correspond to collection for a single subdetector.
     *
     * This method does not impose a memory management model on the
     * caller. (As e.g. returning an object on the heap would do.)
     * The caller can use it to work with stack or heap objects.
     * Call with output==0 is a no-op. (But output should not be garbage, it must be initialized.)
     *
     * Adding an int to tell it to only calculate the detailed track truth for certain tracks: used only by track overlay
     */
    virtual void buildDetailedTrackTruth(DetailedTrackTruthCollection *output,
                                         const TrackCollection& tracks,
                                         const std::vector<const PRD_MultiTruthCollection*>& prdTruth,
                                         const EventContext& ctx) const = 0;
    DeclareInterfaceID(Trk::IDetailedTrackTruthBuilder,1,0);
  };

} // namespace Trk

#endif/*TRKTOOLINTERFACES_IDETAILEDTRACKTRUTHBUILDER_H*/
