// Copyright (C) 2002-2025 CERN for the benefit of the ATLAS collaboration

#ifndef TRIGFPGATRACKSIMOBJECTS_FPGATRACKSIMGNNHIT_H
#define TRIGFPGATRACKSIMOBJECTS_FPGATRACKSIMGNNHIT_H

/**
 * @file FPGATrackSimGNNHit.h
 * @author Jared Burleson - jared.dynes.burleson@cern.ch
 * @date November 27th, 2024
 * @brief FPGATrackSim-specific class to represent an hit in the detector used for GNN pattern recognition. 
 */

class FPGATrackSimGNNHit
{
public:

    ///////////////////////////////////////////////////////////////////////
    // Constructors

    FPGATrackSimGNNHit() = default;
    virtual ~FPGATrackSimGNNHit() = default;

    ///////////////////////////////////////////////////////////////////////
    // Getters/Setters

    // --- Hit Information ---
    void setHitID(unsigned int hitID) { m_hitID = hitID; } // hit index position that relates it to the vector of FPGATrackSimHits
    void setIdentifier(unsigned long int v) { m_identifier = v; } // 32 bit module identifier
    void setRoadID(int v) { m_roadID = v; }
    unsigned int getHitID() { return m_hitID; }
    unsigned long int getIdentifier() { return m_identifier; }
    int getRoadID() { return m_roadID; }

    // --- SpacePoint Information ---
    void setX(float v) { m_x = v; }
    void setY(float v) { m_y = v; }
    void setZ(float v) { m_z = v; }
    void setR(float v) { m_r = v; }
    void setPhi(float v) { m_phi = v; }
    void setEta(float v) { m_eta = v; }
    float getX() const { return m_x; }
    float getY() const { return m_y; }
    float getZ() const { return m_z; }
    float getR() const { return m_r; }
    float getPhi() const { return m_phi; }
    float getEta() const { return m_eta; }


    // --- Cluster Information ---
    void setCluster1X(float v) { m_cluster1_x = v; }
    void setCluster1Y(float v) { m_cluster1_y = v; }
    void setCluster1Z(float v) { m_cluster1_z = v; }
    void setCluster1R(float v) { m_cluster1_r = v; }
    void setCluster1Phi(float v) { m_cluster1_phi = v; }
    void setCluster1Eta(float v) { m_cluster1_eta = v; }
    float getCluster1X() const { return m_cluster1_x; }
    float getCluster1Y() const { return m_cluster1_y; }
    float getCluster1Z() const { return m_cluster1_z; }
    float getCluster1R() const { return m_cluster1_r; }
    float getCluster1Phi() const { return m_cluster1_phi; }
    float getCluster1Eta() const { return m_cluster1_eta; }

    void setCluster2X(float v) { m_cluster1_x = v; }
    void setCluster2Y(float v) { m_cluster1_y = v; }
    void setCluster2Z(float v) { m_cluster1_z = v; }
    void setCluster2R(float v) { m_cluster1_r = v; }
    void setCluster2Phi(float v) { m_cluster1_phi = v; }
    void setCluster2Eta(float v) { m_cluster1_eta = v; }
    float getCluster2X() const { return m_cluster1_x; }
    float getCluster2Y() const { return m_cluster1_y; }
    float getCluster2Z() const { return m_cluster1_z; }
    float getCluster2R() const { return m_cluster1_r; }
    float getCluster2Phi() const { return m_cluster1_phi; }
    float getCluster2Eta() const { return m_cluster1_eta; }

protected:

    // --- Hit Information ---
    unsigned int m_hitID = 0; // hit index position that relates it to the vector of FPGATrackSimHits
    unsigned long int m_identifier = 0; // Global module ID, from offline (32 bit variant)
    int m_roadID = -1; // road ID derived from the label generated by our RoadMakerTool
    
    // --- SpacePoint Information ---
    float m_x = 0;
    float m_y = 0;
    float m_z = 0;
    float m_r = 0;
    float m_phi = 0;
    float m_eta = 0;

    // --- Cluster Information ---
    float m_cluster1_x = 0;
    float m_cluster1_y = 0;
    float m_cluster1_z = 0;
    float m_cluster1_r = 0;
    float m_cluster1_phi = 0;
    float m_cluster1_eta = 0;

    float m_cluster2_x = 0;
    float m_cluster2_y = 0;
    float m_cluster2_z = 0;
    float m_cluster2_r = 0;
    float m_cluster2_phi = 0;
    float m_cluster2_eta = 0;

};

#endif // FPGATRACKSIMGNNHIT_H