/*
  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
*/

/**********************************************************************************
 * @Project: Trigger
 * @Package: TrigParticleTPCnv
 * @class  : TrigElectron_p3
 *
 * @brief persistent partner for TrigElectron
 *
 * @author Andrew Hamilton  <Andrew.Hamilton@cern.ch>  - U. Geneva
 * @author Francesca Bucci  <f.bucci@cern.ch>          - U. Geneva
 * @author Ricardo Goncalo  <r.goncalo@rhul.ac.uk>     - Royal Holloway 
 **********************************************************************************/
#ifndef TRIGPARTICLETPCNV_TRIGELECTRON_P3_H
#define TRIGPARTICLETPCNV_TRIGELECTRON_P3_H

#include "DataModelAthenaPool/ElementLink_p3.h"

#include "EventCommonTPCnv/P4PtEtaPhiMCnv_p1.h"

#include "TrigInDetEvent/TrigInDetTrack.h"

class TrigElectron_p3
{

 public:
  
  TrigElectron_p3() = default;
  virtual ~TrigElectron_p3()  = default;
  friend class TrigElectronCnv_p3;
  
  unsigned int m_roiWord{};
  bool  m_valid{false};
  TrigInDetTrack::AlgoId m_tr_Algo{TrigInDetTrack::NULLID};
  int   m_tr_nr_trt_hits{-999};
  int   m_tr_nr_trt_hithresh_hits{-999};

/*  
  float m_tr_Zvtx; 
  float m_tr_eta_at_calo;  
  float m_tr_phi_at_calo;
  float m_etoverpt;
  float m_cl_eta; 
  float m_cl_phi;
  float m_cl_Rcore;  
  float m_cl_Eratio; 
  float m_cl_EThad;
  float m_cl_e_frac_S0;
  float m_cl_e_frac_S1;
  float m_cl_e_frac_S2;
  float m_cl_e_frac_S3;
*/

  float m_allTheFloats[13]{};

  // ElementLinks to track and cluster
  ElementLinkInt_p3 m_cluster;
  ElementLinkInt_p3 m_track;

  //the P4PtEtaPhiM base class
  P4PtEtaPhiM_p1 m_P4PtEtaPhiM;

};

#endif
