/*
  Copyright (C) 2002-2018 CERN for the benefit of the ATLAS collaboration
*/
/***************************************************************************
                         JetCTP.h  -  description
                            -------------------
   begin                : Friday May 05 2002
   email                : e.moyse@qmul.ac.uk
***************************************************************************/

#ifndef TRIGT1INTERFACES_JETCTP_H
#define TRIGT1INTERFACES_JETCTP_H

namespace LVL1 {

  /**
   *  This class defines the em/tau hadron ROI
   *  which are generated by the LVL1 Calo Trigger.
   *
   * @author moyse
   */
  class JetCTP {

  public:
    JetCTP( unsigned int cableword0 = 0, unsigned int cableword1 = 0 );
    ~JetCTP();

    /** return the data that is sent on cable 0.
    i.e.
    |P|thr10|thr9|thr8|thr7|thr6|thr5|thr4|thr3|thr2|thr1|
    (each thresh is 3 bits)
    */
    unsigned int cableWord0() const;
    /** return the data sent on cable 2
    i.e.
    |P|thr25|thr24|thr23|thr22|thr21|thr20|thr19|thr18|thr17|thr16|thr15|thr14|thr13|thr12|thr11|
    (each thresh is 2 bits)
    */
    unsigned int cableWord1() const;

  private:
    const unsigned int m_cableWord0;
    const unsigned int m_cableWord1;

  }; // class JetCTP

} // namespace LVL1

#include "AthenaKernel/CLASS_DEF.h"
CLASS_DEF( LVL1::JetCTP, 6252, 1 )

#endif // TRIGT1INTERFACES_JETCTP_H
