#!/usr/bin/env python
# Copyright (C) 2002-2025 CERN for the benefit of the ATLAS collaboration

# art-description: Trigger RDO->BS athena test of the Dev_pp_run3_v1 menu
# art-type: build
# art-include: main/Athena/x86_64-el9-gcc14-opt
# art-include: 24.0/Athena
# Skipping art-output which has no effect for build tests.
# If you create a grid version, check art-output in existing grid tests.

from TrigValTools.TrigValSteering.Common import find_file
from TriggerTest.MCExecStep import MCBuildStep
from TrigValTools.TrigValSteering import Test, CheckSteps, Step

ex = MCBuildStep(menu='Dev_pp_run3_v1_TriggerValidation_prescale')
ex.input = 'ttbar'
ex.flags.append('Trigger.writeBS=True')

checkBS = Step.Step("CheckBS")
checkBS.executable = 'trigbs_dumpHLTContentInBS_run3.py'
checkBS.args = ' --l1 --hlt --hltres --stag --sizeSummary'
checkBS.args += ' ' + find_file('*unknown_SingleStream.daq.RAW.*Athena.*.data')
checkBS.required = True
checkBS.auto_report_result = True

test = Test.Test()
test.art_type = 'build'
test.exec_steps = [ex]
test.check_steps = [checkBS] + CheckSteps.default_check_steps(test)

import sys
sys.exit(test.run())
